Revision history
================

0.1.1 2015-06-11

- Rename ``taggit_count`` to ``taggit_counter``

0.1.0 2015-06-10

- Django admin helper classes for django-taggit tags

  - ``TaggitCounter``
  - ``TaggitListFilter``
  - ``TaggitStackedInline``
  - ``TaggitTabularInline``
